define('io.ox/core/gettext', function () {

    'use strict';

    function gt() {
        var gt = function (text) {
            var args = arguments;
            return text.replace(/%(\d+)\$[ds]/g, function (match, index) { return args[index]; });
        };
        gt.pgettext = function () { return gt.apply(null, _.toArray(arguments).slice(1)); };
        gt.npgettext = function () { return gt.apply(null, _.toArray(arguments).slice(2)); };
        return gt;
    }

    return gt;
});

define('gettext', {
    load: function (name, parentRequire, load) {
        parentRequire([name + '.en_US'], load);
    }
});
